
from oncall_slackbot.integrations.nlp import spacy as nlp_spacy
from typing import Optional


def _noop_generate_label(message_text: str) -> Optional[str]:
    return None


if nlp_spacy.is_configured():
    from oncall_slackbot.integrations.nlp.spacy import generate_label
else:
    # Install a noop version as the label generator
    generate_label = _noop_generate_label


def is_backend_present() -> bool:
    """
    Returns whether an NLP backend is actually configured.
    :return: True if a backend is configured, false otherwise
    """
    return generate_label != _noop_generate_label



# -*- coding: utf-8 -*-

import os
import time
import logging

from websocket import create_connection

import slacker_blocks
from slackbot import slackclient

logger = logging.getLogger(__name__)


class BlocksSlackClient(slackclient.SlackClient):
    """
    Overrides to support blocks in calls.
    """

    def __init__(self, token, timeout=None, bot_icon=None, bot_emoji=None, connect=True):
        super(BlocksSlackClient, self).__init__(
            # Never connect since we'll do that here
            token, timeout=timeout, bot_icon=bot_icon, bot_emoji=bot_emoji, connect=False
        )
        # Replace the webapi with the blocks-supporting version
        if timeout is None:
            self.webapi = slacker_blocks.Slacker(self.token)
        else:
            self.webapi = slacker_blocks.Slacker(self.token, timeout=timeout)

        if connect:
            self.rtm_connect()

    def rtm_connect(self):
        reply = self.webapi.rtm.connect().body
        time.sleep(1)
        self.parse_slack_login_data(reply)

    def send_message(self, channel, message, attachments=None, blocks=None, as_user=True, thread_ts=None):
        self.webapi.chat.post_message(
                channel,
                message,
                username=self.login_data['self']['name'],
                icon_url=self.bot_icon,
                icon_emoji=self.bot_emoji,
                attachments=attachments,
                blocks=blocks,
                as_user=as_user,
                thread_ts=thread_ts)

    def parse_slack_login_data(self, login_data):
        self.login_data = login_data
        self.domain = self.login_data['team']['domain']
        self.username = self.login_data['self']['name']
        self.parse_user_data(self.webapi.users.list().body['members'])
        self.parse_channel_data(self.webapi.conversations.list().body['channels'])

        proxy, proxy_port, no_proxy = None, None, None
        if 'http_proxy' in os.environ:
            proxy, proxy_port = os.environ['http_proxy'].split(':')
        if 'no_proxy' in os.environ:
            no_proxy = os.environ['no_proxy']

        self.websocket = create_connection(self.login_data['url'], http_proxy_host=proxy,
                                           http_proxy_port=proxy_port, http_no_proxy=no_proxy)

        self.websocket.sock.setblocking(0)



import os
import subprocess
from setuptools import setup, find_packages


MAJOR_VERSION = '1'

version_file = os.path.join(os.path.dirname(__file__), 'oncall_slackbot/VERSION')
if os.path.exists(version_file):
    # Read version from file
    with open(version_file, 'r', encoding='utf8') as fobj:
        version = fobj.read().strip()
else:
    # Generate the version and store it in the file
    result = subprocess.run('git rev-list --count HEAD', shell=True, capture_output=True, encoding='utf8')
    commit_count = result.stdout.strip()
    version = f'{MAJOR_VERSION}.{commit_count}'
    print(f'Setting version to {version} and writing to {version_file}')
    with open(version_file, 'w', encoding='utf8') as fobj:
        fobj.write(version)

install_requires = (
    'slackbot==0.5.5',
    'pygerduty>=0.38.2',
    'pytz>=2019.3',
    'humanize>=0.5.1',
    'spacy==2.2.3',
)  # yapf: disable

excludes = (
    '*test*',
    '*local_settings*',
) # yapf: disable

setup(name='oncall-slackbot',
      version=version,
      license='MIT',
      description='Extended slackbot made specifically to handle on-call requests',
      author='Brian Saville',
      author_email='bksaville@gmail.com',
      url='http://github.com/bluesliverx/oncall-slackbot',
      platforms=['Any'],
      packages=find_packages(exclude=excludes),
      install_requires=install_requires,
      classifiers=['Development Status :: 4 - Beta',
                   'License :: OSI Approved :: MIT License',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python',
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6'])




import logging
from oncall_slackbot.bot import nlp_label_listen_to, nlp_label_respond_to
from oncall_slackbot.dispatcher import OnCallMessage
from oncall_slackbot.integrations.nlp import spacy


LOGGER = logging.getLogger(__name__)


@nlp_label_listen_to(r'^test')
def process_nlp(message: OnCallMessage):
    # You don't have to process the doc with spacy again, but you can if you want to retrieve more information
    doc = spacy.get_doc(message.body['text'])
    message.reply(f'Message has a test-prefixed nlp label of "{message.nlp_label}", '
                  f'{list((token.text, token.pos_, token.dep_) for token in doc)}')


@nlp_label_respond_to(r'^ignore$')
def process_nlp(message: OnCallMessage):
    message.reply('This message has a nlp label that signifies it is ignored')
